@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -30,22 +30,22 @@ class KDEApplicationDebugSettingPage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit KDEApplicationDebugSettingPage(QWidget *parent = Q_NULLPTR);
+    explicit KDEApplicationDebugSettingPage(QWidget *parent = nullptr);
     ~KDEApplicationDebugSettingPage();
     void fillList(const LoggingCategory::List &list);
     LoggingCategory::List rules() const;
     void insertCategories(const LoggingCategory::List &list);
 protected:
-    bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
-private Q_SLOTS:
+private:
     void slotSelectAll();
     void slotDeselectAll();
-private:
-    KDEApplicationTreeListWidget *mTreeListWidget;
-    KTreeWidgetSearchLine *mTreeListWidgetSearchLine;
-    QPushButton *mEnableDebug;
-    QPushButton *mTurnOffDebug;
+
+    KDEApplicationTreeListWidget *mTreeListWidget = nullptr;
+    KTreeWidgetSearchLine *mTreeListWidgetSearchLine = nullptr;
+    QPushButton *mEnableDebug = nullptr;
+    QPushButton *mTurnOffDebug = nullptr;
 };
 
 #endif // KDEAPPLICATIONDEBUGSETTINGPAGE_H
