@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -103,8 +103,8 @@ void LoadCategoriesJob::start()
     const int number(mCategories.count());
     const QList<KDebugSettingsUtil::LoadLoggingCategory> originalQtCategories = KDebugSettingsUtil::readLoggingQtCategories(mFileName);
     QList<KDebugSettingsUtil::LoadLoggingCategory> qtCategories;
-    Q_FOREACH (KDebugSettingsUtil::LoadLoggingCategory cat, originalQtCategories) {
-        Q_FOREACH(const RenameCategory &catRenamed, mRenameCategories) {
+    for (KDebugSettingsUtil::LoadLoggingCategory cat : originalQtCategories) {
+        for(const RenameCategory &catRenamed : qAsConst(mRenameCategories)) {
             if (cat.logName == catRenamed.originalName) {
                 cat.logName = catRenamed.newName;
                 break;
@@ -117,7 +117,7 @@ void LoadCategoriesJob::start()
         KdeLoggingCategory kdeCat = mCategories.at(i);
 
         bool foundInConfigFile = false;
-        Q_FOREACH (KDebugSettingsUtil::LoadLoggingCategory cat, qtCategories) {
+        for (KDebugSettingsUtil::LoadLoggingCategory cat : qAsConst(qtCategories)) {
             if (cat.logName == kdeCat.logName) {
 
                 LoggingCategory tmp;
@@ -150,7 +150,7 @@ void LoadCategoriesJob::start()
     }
 
     //qDebug()<<" KEEP "<< qtCategories.count();
-    Q_FOREACH (const KDebugSettingsUtil::LoadLoggingCategory &cat, qtCategories) {
+    for (const KDebugSettingsUtil::LoadLoggingCategory &cat : qAsConst(qtCategories)) {
 
         QMapIterator<KDebugSettingsUtil::LoadLoggingCategory::LogType, KDebugSettingsUtil::LoadLoggingCategory::Status> i(cat.loggingTypes);
         while (i.hasNext()) {
